==> wpewebkit_2.34.2.orig.tar.xz: wpewebkit-2.34.2/Source/WebCore/Modules/pictureinpicture/DocumentPictureInPicture.cpp <==
/*
 * Copyright (C) 2019 Carlos Eduardo Ramalho <cadubentzen@gmail.com>.
 * Copyright (C) 2019 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"
#include "DocumentPictureInPicture.h"

#if ENABLE(PICTURE_IN_PICTURE_API)

#include "Document.h"
#include "HTMLVideoElementPictureInPicture.h"
#include "JSDOMPromiseDeferred.h"
#include "PictureInPictureSupport.h"
#include <wtf/IsoMallocInlines.h>

namespace WebCore {

WTF_MAKE_ISO_ALLOCATED_IMPL(DocumentPictureInPicture);

DocumentPictureInPicture::~DocumentPictureInPicture() = default;

bool DocumentPictureInPicture::pictureInPictureEnabled(Document&)
{
    return supportsPictureInPicture();
}

void DocumentPictureInPicture::exitPictureInPicture(Document& document, Ref<DeferredPromise>&& promise)
{
    auto element = document.pictureInPictureElement();

    if (!element) {
        promise->reject(InvalidStateError);
        return;
    }

    HTMLVideoElementPictureInPicture::from(*element)->exitPictureInPicture(WTFMove(promise));
}

DocumentPictureInPicture* DocumentPictureInPicture::from(Document& document)
{
    DocumentPictureInPicture* supplement = static_cast<DocumentPictureInPicture*>(Supplement<Document>::from(&document, supplementName()));
    if (!supplement) {
        auto newSupplement = makeUnique<DocumentPictureInPicture>();
        supplement = newSupplement.get();
        provideTo(&document, supplementName(), WTFMove(newSupplement));
    }
    return supplement;
}

} // namespace WebCore

#endif // ENABLE(PICTURE_IN_PICTURE_API)

==> wpewebkit_2.46.5.orig.tar.xz: wpewebkit-2.46.5/Source/WebCore/Modules/pictureinpicture/DocumentPictureInPicture.cpp <==
/*
 * Copyright (C) 2019 Carlos Eduardo Ramalho <cadubentzen@gmail.com>.
 * Copyright (C) 2019 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"
#include "DocumentPictureInPicture.h"

#if ENABLE(PICTURE_IN_PICTURE_API)

#include "Document.h"
#include "HTMLVideoElementPictureInPicture.h"
#include "JSDOMPromiseDeferred.h"
#include "PictureInPictureSupport.h"
#include <wtf/TZoneMallocInlines.h>

namespace WebCore {

WTF_MAKE_TZONE_OR_ISO_ALLOCATED_IMPL(DocumentPictureInPicture);

DocumentPictureInPicture::~DocumentPictureInPicture() = default;

bool DocumentPictureInPicture::pictureInPictureEnabled(Document&)
{
    return supportsPictureInPicture();
}

void DocumentPictureInPicture::exitPictureInPicture(Document& document, Ref<DeferredPromise>&& promise)
{
    auto element = document.pictureInPictureElement();

    if (!element) {
        promise->reject(ExceptionCode::InvalidStateError);
        return;
    }

    HTMLVideoElementPictureInPicture::from(*element)->exitPictureInPicture(WTFMove(promise));
}

DocumentPictureInPicture* DocumentPictureInPicture::from(Document& document)
{
    DocumentPictureInPicture* supplement = static_cast<DocumentPictureInPicture*>(Supplement<Document>::from(&document, supplementName()));
    if (!supplement) {
        auto newSupplement = makeUnique<DocumentPictureInPicture>();
        supplement = newSupplement.get();
        provideTo(&document, supplementName(), WTFMove(newSupplement));
    }
    return supplement;
}

} // namespace WebCore

#endif // ENABLE(PICTURE_IN_PICTURE_API)
